@@ -38,8 +38,7 @@ def send_log_email():
                                               'Email_Content', 'Signature',
                                               'Email_Us', 'FAQ_URL',
                                               'Unsubscribe_Email_ID',
-                                              'Content_Type'
-                                              ).first()
+                                              'Content_Type', 'Banner').first()
         if email_configuration:
             send_notifications(email, sender, email_configuration)
         else:
@@ -61,8 +60,7 @@ def send_log_email_with_msg(email, msg):
                                            'Email_Content', 'Signature',
                                            'Email_Us', 'FAQ_URL',
                                            'Unsubscribe_Email_ID',
-                                           'Content_Type'
-                                           ).first()
+                                           'Content_Type', 'Banner').first()
         if email_configuration:
             send_notifications_with_msg(email, sender,
                                         msg, email_configuration)
