@@ -6,6 +6,7 @@ from django.conf import settings
 from django.core.mail import EmailMessage
 
 logger = logging.getLogger('dict_config_logger')
+host = getattr(settings, 'SERVER_IP', False)
 
 
 def send_notifications(email, sender, email_configuration):
@@ -34,7 +35,8 @@ def send_notifications(email, sender, email_configuration):
         signature=email_configuration.get('Signature'),
         email_us=email_configuration.get('Email_Us'),
         faq_url=email_configuration.get('FAQ_URL'),
-        unsubscribe=email_configuration.get('Unsubscribe_Email_ID'))
+        unsubscribe=email_configuration.get('Unsubscribe_Email_ID'),
+        banner=host + "/media/" + email_configuration.get('Banner'))
     # Define the attachment part and encode it using MIMEApplication.
     att = MIMEApplication(open(ATTACHMENT, 'rb').read())
 
@@ -81,7 +83,8 @@ def send_notifications_with_msg(email, sender, msg, email_configuration):
         signature=email_configuration.get('Signature'),
         email_us=email_configuration.get('Email_Us'),
         faq_url=email_configuration.get('FAQ_URL'),
-        unsubscribe=email_configuration.get('Unsubscribe_Email_ID'))
+        unsubscribe=email_configuration.get('Unsubscribe_Email_ID'),
+        banner=host + "/media/" + email_configuration.get('Banner'))
 
     for each_recipient in RECIPIENT:
         try:
